@@ -10,7 +10,7 @@ from tqdm import tqdm
 ##################################################### PYTHOLINO ######################################################
 
 def pytholino_alert(url, alert):
-    payload = "{'Alerta': {}}".format(alert)
+    payload = "{'Alerta': '" + alert + "'}"
     a = requests.request("POST", url, data=payload)
 
 
